@@ -31,7 +31,7 @@
 #include "DotIO.h"
 #include "colorutil.h"
 
-#ifdef WIN32 /*dependencies*/
+#ifdef _WIN32 /*dependencies*/
     #pragma comment( lib, "cgraph.lib" )
     #pragma comment( lib, "gvc.lib" )
     #pragma comment( lib, "ingraphs.lib" )
@@ -41,7 +41,7 @@
     #pragma comment( lib, "neatogen.lib" )
     #pragma comment( lib, "rbtree.lib" )
     #pragma comment( lib, "cdt.lib" )
-#endif   /* not WIN32_DLL */
+#endif   /* not _WIN32 */
 
 enum {POINTS_ALL = 1, POINTS_LABEL, POINTS_RANDOM};
 enum {maxlen = 10000000};
@@ -54,32 +54,6 @@ typedef struct {
   int clustering_method;
 } opts_t;
 
-#if 0
-void *gmalloc(size_t nbytes)
-{
-    char *rv;
-    if (nbytes == 0)
-        return NULL;
-    rv = malloc(nbytes);
-    if (rv == NULL) {
-        fprintf(stderr, "out of memory\n");
-        abort();
-    }
-    return rv;
-}
-
-void *grealloc(void *ptr, size_t size)
-{
-    void *p = realloc(ptr, size);
-    if (p == NULL && size) {
-        fprintf(stderr, "out of memory\n");
-        abort();
-    }
-    return p;
-}
-
-#endif
-
 static char* usestr =
 "    -C k - generate no more than k clusters (0)\n\
        0 : no limit\n\
