@@ -11,9 +11,7 @@
  * Contributors: See CVS logs. Details at http://www.graphviz.org/
  *************************************************************************/
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -22,11 +20,7 @@
 #include "QuadTree.h"
 #include <time.h>
 #include "SparseMatrix.h"
-#ifdef HAVE_GETOPT_H
 #include <getopt.h>
-#else
-#include "compat_getopt.h"
-#endif
 #include "string.h"
 #include "make_map.h"
 #include "spring_electrical.h"
@@ -38,7 +32,7 @@
 #include "colorutil.h"
 #include "color_palette.h"
 
-#ifdef WIN32
+#ifdef _WIN32
 #define strdup(x) _strdup(x)
 #endif
 enum {POINTS_ALL = 1, POINTS_LABEL, POINTS_RANDOM};
@@ -46,58 +40,6 @@ enum {maxlen = 10000000};
 enum {MAX_GRPS = 10000};
 static char swork[maxlen];
 
-#ifdef WIN32
-    #pragma comment( lib, "cgraph.lib" )
-    #pragma comment( lib, "gvc.lib" )
-    #pragma comment( lib, "ingraphs.lib" )
-    #pragma comment( lib, "sparse.lib" )
-    #pragma comment( lib, "neatogen.lib" )
-    #pragma comment( lib, "gvc.lib" )
-    #pragma comment( lib, "pathplan.lib" )
-    #pragma comment( lib, "neatogen.lib" )
-    #pragma comment( lib, "edgepaintlib.lib" )
-    #pragma comment( lib, "circogen.lib" )
-    #pragma comment( lib, "twopigen.lib" )
-    #pragma comment( lib, "fdpgen.lib" )
-    #pragma comment( lib, "sparse.lib" )
-    #pragma comment( lib, "cdt.lib" )
-    #pragma comment( lib, "gts.lib" )
-    #pragma comment( lib, "glib-2.0.lib" )
-    #pragma comment( lib, "vpsc.lib" )
-    #pragma comment( lib, "patchwork.lib" )
-    #pragma comment( lib, "gvortho.lib" )
-    #pragma comment( lib, "sfdp.lib" )
-    #pragma comment( lib, "rbtree.lib" )
-#endif   /* not WIN32_DLL */
-
-
-
-#if 0
-void *gmalloc(size_t nbytes)
-{
-    char *rv;
-    if (nbytes == 0)
-        return NULL;
-    rv = malloc(nbytes);
-    if (rv == NULL) {
-        fprintf(stderr, "out of memory\n");
-        abort();
-    }
-    return rv;
-}
-
-void *grealloc(void *ptr, size_t size)
-{
-    void *p = realloc(ptr, size);
-    if (p == NULL && size) {
-        fprintf(stderr, "out of memory\n");
-        abort();
-    }
-    return p;
-}
-
-#endif
-
 typedef struct {
     char* cmd;
     char **infiles; 
@@ -109,6 +51,7 @@ typedef struct {
     real bbox_margin[2]; 
     int whatout;
     int useClusters;
+    int clusterMethod;
     int plotedges;
     int color_scheme;
     real line_width;
@@ -196,13 +139,13 @@ static char* usestr =
       10 : light grey\n\
     -c_opacity=xx - 2-character hex string for opacity of polygons\n\
     -C k - generate at most k clusters. (0)\n\
-    -d s - seed used to calculate Fielder vector for optimal coloring\n\
+    -d s - seed used to calculate Fiedler vector for optimal coloring\n\
     -D   - use top-level cluster subgraphs to specify clustering\n\
     -e   - show edges\n\
     -g c - bounding box color. If not specified, a bounding box is not drawn.\n\
     -h k - number of artificial points added to maintain bridge between endpoints (0)\n\
     -highlight=k - only draw cluster k\n\
-    -k   - increase randomesss of boundary\n\
+    -k   - increase randomness of boundary\n\
     -l s - specify label\n\
     -m v - bounding box margin. If 0, auto-assigned (0)\n\
     -o <file> - put output in <file> (stdout)\n\
@@ -213,7 +156,7 @@ static char* usestr =
        2 : label points\n\
        3 : random/artificial points\n\
     -r k - number of random points k used to define sea and lake boundaries. If 0, auto assigned. (0)\n\
-    -s v - depth of the sea and lake shores in points. If 0, auto assigned. (0)\n\
+    -s v - depth of the sea and lake shores in points. If < 0, auto assigned. (0)\n\
     -t n - improve contiguity up to n times. (0)\n\
     -v   - verbose\n\
     -z c - polygon line color (black)\n";
@@ -229,7 +172,7 @@ static char* usestr =
     /* e.g., 
        1 [cluster=10, clustercolor="#ff0000"]
        2 [cluster=10]
-       (and no ther nodes are in cluster10)
+       (and no other nodes are in cluster10)
 
        then since we can only use 1 color for the cluster 10, both 1 and 2 will be colored based on the color of node 2. However if you have
 
@@ -285,6 +228,7 @@ init(int argc, char **argv, params_t* pm)
   pm->shore_depth_tol = 0;
   pm->highlight_cluster = 0;
   pm->useClusters = 0;
+  pm->clusterMethod = CLUSTERING_MODULARITY;
   pm->plotedges = 0;
   pm->whatout = 0;
   pm->show_points = 0;
@@ -310,7 +254,7 @@ init(int argc, char **argv, params_t* pm)
   pm->bbox_margin[0] =  pm->bbox_margin[1] = 0;
 
   opterr = 0;
-  while ((c = getopt(argc, argv, ":evODko:m:s:r:p:c:C:l:b:g:t:a:h:z:d:")) != -1) {
+  while ((c = getopt(argc, argv, ":evODQko:m:s:r:p:c:C:l:b:g:t:a:h:z:d:")) != -1) {
     switch (c) {
     case 'm':
       if ((sscanf(optarg,"%lf",&s) > 0) && (s != 0)){
@@ -319,6 +263,9 @@ init(int argc, char **argv, params_t* pm)
         usage(cmd, 1);
       }
       break;
+    case 'Q':
+      pm->clusterMethod = CLUSTERING_MQ;
+      break;
 #if 0
     case 'q':
       if ((sscanf(optarg,"%d",&r) > 0) && r >=0 && r <=OUT_PROCESSING){
@@ -566,6 +513,7 @@ makeMap (SparseMatrix graph, int n, real* x, real* width, int* grouping,
 				 pm->shore_depth_tol, edge_bridge_tol, &xcombined, &nverts, &x_poly, &npolys, &poly_lines, 
 				 &polys, &polys_groups, &poly_point_map, &country_graph, pm->highlight_cluster, &flag);
 
+  if (Verbose) fprintf(stderr,"nart = %d\n",nart);
   /* compute a good color permutation */
   if (pm->color_optimize && country_graph && rgb_r && rgb_g && rgb_b) 
     map_optimal_coloring(pm->seed, country_graph, rgb_r,  rgb_g, rgb_b);
@@ -708,7 +656,7 @@ static void mapFromGraph (Agraph_t* g, params_t* pm)
 
   initDotIO(g);
   graph = Import_coord_clusters_from_dot(g, pm->maxcluster, pm->dim, &n, &width, &x, &grouping, 
-					   &rgb_r,  &rgb_g,  &rgb_b,  &fsz, &labels, pm->color_scheme, CLUSTERING_MODULARITY, pm->useClusters);
+					   &rgb_r,  &rgb_g,  &rgb_b,  &fsz, &labels, pm->color_scheme, pm->clusterMethod, pm->useClusters);
   makeMap (graph, n, x, width, grouping, labels, fsz, rgb_r, rgb_g, rgb_b, pm, g);
 }
 
