@@ -22,19 +22,13 @@
 
 #include <getopt.h>
 
-#define N_NEW(n,t)       (t*)malloc((n)*sizeof(t))
+#define N_NEW(n,t)       (t*)calloc((n),sizeof(t))
 
 static int Verbose;
 static char* gname = "";
 static FILE *outFile;
 static char *CmdName;
 static char **Files;
-#ifdef WIN32 //*dependencies
-    #pragma comment( lib, "cgraph.lib" )
-    #pragma comment( lib, "cdt.lib" )
-    #pragma comment( lib, "ingraphs.lib" )
-    #pragma comment( lib, "gvc.lib" )
-#endif
 
 static FILE *getFile(void)
 {
