@@ -73,7 +73,7 @@
 #include <assert.h>
 
 #define NEW(t)       (t*)malloc(sizeof(t))
-#define N_NEW(n,t)   (t*)malloc((n)*sizeof(t))
+#define N_NEW(n,t)   (t*)calloc((n),sizeof(t))
 #define RALLOC(size,ptr,type) ((type*)realloc(ptr,(size)*sizeof(type)))
 
 typedef unsigned short ushort;
