@@ -56,7 +56,7 @@ struct slist {
 };
 
 #define NEW(t)      (t*)malloc(sizeof(t))
-#define N_NEW(n,t)  (t*)malloc((n)*sizeof(t))
+#define N_NEW(n,t)  (t*)calloc((n),sizeof(t))
 /* Round x up to next multiple of y, which is a power of 2 */
 #define ROUND2(x,y) (((x) + ((y)-1)) & ~((y)-1))
 
@@ -773,7 +773,7 @@ int main(int argc, char **argv)
     Agraph_t *G;
     Agraph_t *prev = 0;
     FILE *inFile;
-    int rv, gcnt = 0;
+    int rv = 0, gcnt = 0;
 
 #ifdef HAVE_EXPAT
     initargs(argc, argv);
