@@ -15,11 +15,6 @@
  * Written by Emden Gansner
  */
 
-#ifdef WIN32 /*dependencies*/
-    #pragma comment( lib, "cgraph.lib" )
-    #pragma comment( lib, "ingraphs.lib" )
-#endif
-
 #include "config.h"
 
 #include <stdio.h>
@@ -458,6 +453,8 @@ closeOpen (void)
 	fprintf(opts.outfile, "}\ngraph {\n");
 }
 
+extern void makeTetrix(int depth, edgefn ef);
+
 int main(int argc, char *argv[])
 {
     GraphType graphType;
