@@ -18,15 +18,6 @@
 #include    <expat.h>
 #include    <ctype.h>
 
-#ifdef WIN32 //*dependencies
-    #pragma comment( lib, "cgraph.lib" )
-    #pragma comment( lib, "cdt.lib" )
-    #pragma comment( lib, "ingraphs.lib" )
-    #pragma comment( lib, "gvc.lib" )
-    #pragma comment( lib, "libexpat.lib" )
-#endif
-
-
 #ifndef XML_STATUS_ERROR
 #define XML_STATUS_ERROR 0
 #endif
@@ -58,7 +49,7 @@ struct slist {
 };
 
 #define NEW(t)      (t*)malloc(sizeof(t))
-#define N_NEW(n,t)  (t*)malloc((n)*sizeof(t))
+#define N_NEW(n,t)  (t*)calloc((n),sizeof(t))
 /* Round x up to next multiple of y, which is a power of 2 */
 #define ROUND2(x,y) (((x) + ((y)-1)) & ~((y)-1))
 
