@@ -14,7 +14,7 @@
 #include "config.h"
 
 #include <stdio.h>
-#ifndef WIN32
+#ifndef _WIN32
 #include <unistd.h>
 #endif
 #include <stdlib.h>
@@ -27,13 +27,6 @@
 #include "ingraphs.h"
 #include "generic_list.h"
 
-
-#ifdef WIN32 //*dependencies
-    #pragma comment( lib, "cgraph.lib" )
-    #pragma comment( lib, "ingraphs.lib" )
-#endif
-
-
 /* structure to hold an attribute specified on the commandline */
 typedef struct strattr_s {
     char *n;
@@ -48,7 +41,7 @@ generic_list_t *addnode(generic_list_t * l, char *n);
 
 int verbose = 0;		/* Flag to indicate verbose message output */
 
-/* wrapper to match libagraph conventions with libingraph */
+/* wrapper to match libcgraph conventions with libingraph */
 Agraph_t *gread(FILE * fp);
 
 #define NDNAME "mk"
@@ -258,7 +251,7 @@ Options:\n\
 Both options `-n' and `-N' can be used multiple times on the command line.\n", progname);
 }
 
-/* wrapper to match libagraph conventions with libingraph */
+/* wrapper to match libcgraph conventions with libingraph */
 Agraph_t *gread(FILE * fp)
 {
     return agread(fp, (Agdisc_t *) 0);
