@@ -777,20 +777,3 @@ int strmatch(const char *s, const char *p)
 {
     return strgrpmatch(s, p, NiL, 0, STR_MAXIMAL | STR_LEFT | STR_RIGHT);
 }
-
-/*
- * leading substring match
- * first char after end of substring returned
- * 0 returned if no match
- *
- * OBSOLETE: use strgrpmatch()
- */
-
-char *strsubmatch(const char *s, const char *p, int flags)
-{
-    int match[2];
-
-    return strgrpmatch(s, p, match, 1,
-		       (flags ? STR_MAXIMAL : 0) | STR_LEFT) ? (char *) s +
-	match[1] : (char *) 0;
-}
