@@ -14,7 +14,7 @@
 #define EXTERN
 #include <cghdr.h>
 
-const char AgraphVersion[] = "VERSION";
+const char AgraphVersion[] = PACKAGE_VERSION;
 
 /*
  * this code sets up the resource management discipline
@@ -45,7 +45,7 @@ Agraph_t *agopen(char *name, Agdesc_t desc, Agdisc_t * arg_disc)
 {
     Agraph_t *g;
     Agclos_t *clos;
-    unsigned long gid;
+    IDTYPE gid;
 
     clos = agclos(arg_disc);
     g = clos->disc.mem->alloc(clos->state.mem, sizeof(Agraph_t));
@@ -154,7 +154,7 @@ int agclose(Agraph_t * g)
     return SUCCESS;
 }
 
-unsigned long agnextseq(Agraph_t * g, int objtype)
+uint64_t agnextseq(Agraph_t * g, int objtype)
 {
     return ++(g->clos->seq[objtype]);
 }
@@ -239,9 +239,9 @@ int agdegree(Agraph_t * g, Agnode_t * n, int want_in, int want_out)
 	return rv;
 }
 
-int agraphidcmpf(Dict_t * d, void *arg0, void *arg1, Dtdisc_t * disc)
+static int agraphidcmpf(Dict_t * d, void *arg0, void *arg1, Dtdisc_t * disc)
 {
-    long	v;
+    ptrdiff_t	v;
     Agraph_t *sg0, *sg1;
     sg0 = (Agraph_t *) arg0;
     sg1 = (Agraph_t *) arg1;
