@@ -828,7 +828,7 @@ void free_html_text(htmltxt_t * t)
     free(t);
 }
 
-void free_html_img(htmlimg_t * ip)
+static void free_html_img(htmlimg_t * ip)
 {
     free(ip->src);
     free(ip);
@@ -1333,7 +1333,7 @@ static int processTbl(graph_t * g, htmltbl_t * tbl, htmlenv_t * env)
  * A cell spanning columns contributes proportionately to each column
  * it is in.
  */
-void sizeLinearArray(htmltbl_t * tbl)
+static void sizeLinearArray(htmltbl_t * tbl)
 {
     htmlcell_t *cp;
     htmlcell_t **cells;
@@ -1375,7 +1375,7 @@ static char *nnames[] = {
 /* nToName:
  * Convert int to its decimal string representation.
  */
-char *nToName(int c)
+static char *nToName(int c)
 {
     static char name[100];
 
@@ -1453,7 +1453,7 @@ checkEdge (graph_t* g, node_t* t, node_t* h, int sz)
  * Ditto for rows.
  *
  */
-void makeGraphs(htmltbl_t * tbl, graph_t * rowg, graph_t * colg)
+static void makeGraphs(htmltbl_t * tbl, graph_t * rowg, graph_t * colg)
 {
     htmlcell_t *cp;
     htmlcell_t **cells;
@@ -1510,7 +1510,7 @@ void makeGraphs(htmltbl_t * tbl, graph_t * rowg, graph_t * colg)
  * give the coordinate, so to get the width/height, we have
  * to subtract the previous value.
  */
-void setSizes(htmltbl_t * tbl, graph_t * rowg, graph_t * colg)
+static void setSizes(htmltbl_t * tbl, graph_t * rowg, graph_t * colg)
 {
     int i;
     node_t *n;
@@ -1538,7 +1538,7 @@ void setSizes(htmltbl_t * tbl, graph_t * rowg, graph_t * colg)
  * a dag on a chain. We then run network simplex, using
  * LR_balance.
  */
-void sizeArray(htmltbl_t * tbl)
+static void sizeArray(htmltbl_t * tbl)
 {
     graph_t *rowg;
     graph_t *colg;
