@@ -11,13 +11,12 @@
  * Contributors: See CVS logs. Details at http://www.graphviz.org/
  *************************************************************************/
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "render.h"
 #include "pathplan.h"
 #include <setjmp.h>
+#include <stdlib.h>
 
 #ifdef UNUSED
 static box *bs = NULL;
@@ -64,6 +63,7 @@ static void printboxes(int boxn, boxf* boxes)
     Show_boxes[Show_cnt+1] = NULL;
 }
 
+#if DEBUG > 1
 static void psprintpolypts(Ppoint_t * p, int sz)
 {
     int i;
@@ -98,6 +98,7 @@ static void psprintpointf(pointf p)
 	    p.x, p.y);
     fprintf(stderr, "grestore\n");
 }
+#endif
 
 static void psprintspline(Ppolyline_t spl)
 {
@@ -288,7 +289,7 @@ int
 routesplinesinit()
 {
     if (++routeinit > 1) return 0;
-    if (!(ps = N_GNEW(PINC, pointf))) {
+    if (!(ps = calloc(PINC, sizeof(pointf)))) {
 	agerr(AGERR, "routesplinesinit: cannot allocate ps\n");
 	return 1;
     }
@@ -385,7 +386,7 @@ limitBoxes (boxf* boxes, int boxn, pointf *pps, int pn, int delta)
  * the box can be shrunk to the minimum width. The extra space can then be used by other
  * edges. 
  *
- * If a catastrophic error, return NULL.
+ * If a catastrophic error, return NULL and npoints is 0.
  */
 static pointf *_routesplines(path * pp, int *npoints, int polyline)
 {
@@ -403,6 +404,7 @@ static pointf *_routesplines(path * pp, int *npoints, int polyline)
     int loopcnt, delta = INIT_DELTA;
     boolean unbounded;
 
+    *npoints = 0;
     nedges++;
     nboxes += pp->nbox;
 
@@ -532,7 +534,7 @@ static pointf *_routesplines(path * pp, int *npoints, int polyline)
     if (flip) {
 	int i;
 	for (bi = 0; bi < boxn; bi++) {
-	    int v = boxes[bi].UR.y;
+	    double v = boxes[bi].UR.y;
 	    boxes[bi].UR.y = -1*boxes[bi].LL.y;
 	    boxes[bi].LL.y = -v;
 	}
@@ -633,7 +635,6 @@ static pointf *_routesplines(path * pp, int *npoints, int polyline)
 	agerr(AGWARN, "Unable to reclaim box space in spline routing for edge \"%s\" -> \"%s\". Something is probably seriously wrong.\n", agnameof(agtail(realedge)), agnameof(aghead(realedge)));
 	make_polyline (pl, &polyspl);
 	limitBoxes (boxes, boxn, polyspl.ps, polyspl.pn, INIT_DELTA);
-	free (polyspl.ps);
     }
 
     *npoints = spl.pn;
@@ -846,7 +847,7 @@ static int mkspacep(int size)
 {
     if (size > maxpn) {
 	int newmax = maxpn + (size / PINC + 1) * PINC;
-	ps = RALLOC(newmax, ps, pointf);
+	ps = realloc(ps, newmax * sizeof(pointf));
 	if (!ps) {
 	    agerr(AGERR, "cannot re-allocate ps\n");
 	    return 1;
@@ -902,6 +903,252 @@ static pointf get_centroid(Agraph_t *g)
     return sum;
 }
 
+#define __CYCLE_CENTROID 
+#ifdef __CYCLE_CENTROID
+//generic vector structure
+typedef struct _tag_vec
+{
+    void** _mem;
+    size_t _elems;
+    size_t _capelems;
+} vec;
+
+static vec* vec_new(void)
+{
+    vec* pvec = (vec*)malloc(sizeof(vec));
+    pvec->_capelems = 10;
+    pvec->_elems = 0;
+    pvec->_mem = (void**)malloc(pvec->_capelems * sizeof(void*));
+    return pvec;
+}
+
+static void vec_delete(vec* pvec)
+{
+    free(pvec->_mem);
+    free(pvec);
+}
+
+static void vec_push_back(vec* pvec, void* data)
+{
+    if (pvec->_elems == pvec->_capelems) {
+		pvec->_capelems += 10;
+		pvec->_mem = (void**)realloc(pvec->_mem, pvec->_capelems * sizeof(void*));
+	}
+    pvec->_mem[pvec->_elems++] = data;  
+}
+
+static size_t vec_length(vec* pvec)
+{
+    return pvec->_elems;
+}
+
+static void* vec_get(vec* pvec, size_t index)
+{
+    assert(index < pvec->_elems);
+    return pvec->_mem[index];
+}
+
+static void* vec_pop(vec* pvec)
+{
+	if (pvec->_elems > 0)
+		return pvec->_mem[--pvec->_elems];
+	return NULL;
+}
+
+static boolean vec_contains(vec* pvec, void* item) 
+{
+	size_t i;
+
+	for (i=0; i < pvec->_elems; ++i) {
+		if (pvec->_mem[i] == item)
+			return TRUE;
+	}
+
+	return FALSE;
+}
+
+static vec* vec_copy(vec* pvec)
+{
+    vec* nvec = (vec*)malloc(sizeof(vec));
+    nvec->_capelems = pvec->_capelems;
+    nvec->_elems = pvec->_elems;
+    nvec->_mem = (void**)malloc(pvec->_capelems * sizeof(void*));
+	memcpy(nvec->_mem, pvec->_mem, pvec->_elems * sizeof(void*));
+    return nvec;
+}
+//end generic vector structure
+
+static boolean cycle_contains_edge(vec* cycle, edge_t* edge)
+{
+	node_t* start = agtail(edge);
+	node_t* end = aghead(edge);
+	node_t* c_start;
+	node_t* c_end;
+
+	size_t cycle_len = vec_length(cycle);
+	size_t i;
+
+	for (i=0; i < cycle_len; ++i) {
+		if (i == 0) {
+			c_start = (node_t*)vec_get(cycle, cycle_len-1);
+		} else {
+			c_start = (node_t*)vec_get(cycle, i-1);
+		}
+	
+		c_end = (node_t*)vec_get(cycle, i);
+
+		if (c_start == start && c_end == end)
+			return TRUE;
+	}
+
+
+	return FALSE;
+}
+
+static boolean is_cycle_unique(vec* cycles, vec* cycle) 
+{
+	size_t cycle_len = vec_length(cycle);
+	size_t n_cycles = vec_length(cycles);
+	size_t c; //cycles counter
+	size_t i; //node counter
+
+	vec* cur_cycle;
+	size_t cur_cycle_len;
+	void* cur_cycle_item;
+	boolean all_items_match;
+
+	for (c=0; c < n_cycles; ++c) {
+		cur_cycle = (vec*)vec_get(cycles, c);
+		cur_cycle_len = vec_length(cur_cycle);
+
+		//if all the items match in equal length cycles then we're not unique
+		if (cur_cycle_len == cycle_len) {
+			all_items_match = TRUE;
+			for (i=0; i < cur_cycle_len; ++i) {
+				cur_cycle_item = vec_get(cur_cycle, i);
+				if (!vec_contains(cycle, cur_cycle_item)) {
+					all_items_match = FALSE;
+					break;
+				}
+			}
+			if (all_items_match)
+				return FALSE;
+		}
+	}
+
+	return TRUE;
+}
+
+static void dfs(graph_t *g, node_t* search, vec* visited, node_t* end, vec* cycles)
+{
+	edge_t* e;
+	node_t* n;
+
+	if (vec_contains(visited, search)) {
+		if (search == end) {
+			if (is_cycle_unique(cycles, visited)) {
+				vec* cycle = vec_copy(visited);
+				vec_push_back(cycles, cycle);
+			}
+		}
+	} else {
+		vec_push_back(visited, search);
+		for (e = agfstout(g, search); e; e = agnxtout(g, e)) {
+			n = aghead(e);
+			dfs(g, n, visited, end, cycles);
+		}
+		vec_pop(visited);
+	}
+}
+
+static vec* find_all_cycles(graph_t *g)
+{
+    node_t *n;
+
+    vec* alloced_cycles = vec_new(); //vector of vectors of nodes -- AKA cycles to delete
+    vec* cycles = vec_new(); //vector of vectors of nodes AKA a vector of cycles
+    vec* cycle;
+
+    for (n = agfstnode(g); n; n = agnxtnode(g, n)) {
+		cycle = vec_new();
+		vec_push_back(alloced_cycles, cycle); //keep track of all items we allocate to clean up at the end of this function
+		
+		dfs(g, n, cycle, n, cycles);
+	}
+	
+	vec_delete(alloced_cycles); //cycles contains copied vecs
+    return cycles;
+}
+
+static vec* find_shortest_cycle_with_edge(vec* cycles, edge_t* edge, size_t min_size)
+{
+	size_t c; //cycle counter
+	size_t cycles_len = vec_length(cycles);
+	vec* cycle;
+	size_t cycle_len; 
+	vec* shortest = 0;
+
+	for (c=0; c < cycles_len; ++c) {
+		cycle = (vec*)vec_get(cycles, c);
+		cycle_len = vec_length(cycle);
+
+		if (cycle_len < min_size)
+			continue;
+
+		if (!shortest || vec_length(shortest) > cycle_len) {
+			if (cycle_contains_edge(cycle, edge)) {
+				shortest = cycle;
+			}
+		}
+	}
+	return shortest;
+}
+
+static pointf get_cycle_centroid(graph_t *g, edge_t* edge)
+{
+	static vec* cycles = 0;
+	static graph_t* ref_g = 0;
+
+	if (cycles == 0 || ref_g != g) {
+		//free the memory we're using to hold the previous cycles
+		if (cycles != 0) {
+			size_t i;
+			for (i=0; i < vec_length(cycles); ++i) {
+				vec_delete(vec_get(cycles, i));
+			}
+			vec_delete(cycles);
+		}
+		cycles = find_all_cycles(g);
+		ref_g = g;
+	}
+
+	//find the center of the shortest cycle containing this edge
+	//cycles of length 2 do their own thing, we want 3 or
+	vec* cycle = find_shortest_cycle_with_edge(cycles, edge, 3);
+	size_t cycle_len;
+	size_t cnt = 0;
+    pointf sum = {0.0, 0.0};
+	size_t idx; //edge index
+	node_t *n;
+
+	if (!cycle)
+		return get_centroid(g);
+
+	cycle_len = vec_length(cycle);
+
+	for (idx=0; idx < cycle_len; ++idx) {
+		n = (node_t*)vec_get(cycle, idx);
+		sum.x += ND_coord(n).x;
+        sum.y += ND_coord(n).y;
+        cnt++;
+	}
+
+	sum.x = sum.x / cnt;
+    sum.y = sum.y / cnt;
+    return sum;
+}
+#endif
+
 static void bend(pointf spl[4], pointf centroid)
 {
     pointf  midpt,a;
@@ -918,6 +1165,7 @@ static void bend(pointf spl[4], pointf centroid)
         double vX = centroid.x - midpt.x;
         double vY = centroid.y - midpt.y;
         double magV = sqrt(vX*vX + vY*vY);
+	if (magV == 0) return;  /* if midpoint == centroid, don't divide by zero */
         a.x = midpt.x - vX / magV * r;      /* + would be closest point */
         a.y = midpt.y - vY / magV * r;
     }
@@ -941,7 +1189,7 @@ makeStraightEdge(graph_t * g, edge_t * e, int et, splineInfo* sinfo)
 
     e_cnt = 1;
     e0 = e;
-    while ((e0 = ED_to_virt(e0))) e_cnt++;
+    while ((e0 != ED_to_virt(e0)) && (e0 = ED_to_virt(e0))) e_cnt++;
 
     if (e_cnt <= MAX_EDGE)
 	edges = elist;
@@ -979,7 +1227,11 @@ makeStraightEdges(graph_t * g, edge_t** edges, int e_cnt, int et, splineInfo* si
     p = dumb[1] = dumb[0] = add_pointf(ND_coord(n), ED_tail_port(e).p);
     q = dumb[2] = dumb[3] = add_pointf(ND_coord(head), ED_head_port(e).p);
     if ((e_cnt == 1) || Concentrate) {
-	if (curved) bend(dumb,get_centroid(g));
+#ifndef __CYCLE_CENTROID
+    if (curved) bend(dumb,get_centroid(g));
+#else
+	if (curved) bend(dumb,get_cycle_centroid(g, edges[0]));
+#endif
 	clip_and_install(e, aghead(e), dumb, 4, sinfo);
 	addEdgeLabels(g, e, p, q);
 	return;
