@@ -33,7 +33,7 @@
 		    gvplugin_installed_t * typeptr);
     extern gvplugin_available_t *gvplugin_load(GVC_t * gvc, api_t api, const char *type);
     extern gvplugin_library_t *gvplugin_library_load(GVC_t *gvc, char *path);
-    extern api_t gvplugin_api(char *str);
+    extern api_t gvplugin_api(const char *str);
     extern char * gvplugin_api_name(api_t api);
     extern void gvplugin_write_status(GVC_t * gvc);
     extern char *gvplugin_list(GVC_t * gvc, api_t api, const char *str);
@@ -113,7 +113,7 @@
 			int arrow_at_start, int arrow_at_end, boolean filled);
     extern void gvrender_polyline(GVJ_t * job, pointf * AF, int n);
     extern void gvrender_comment(GVJ_t * job, char *str);
-    extern void gvrender_usershape(GVJ_t * job, char *name, pointf * AF, int n, boolean filled, char *imagescale);
+    extern void gvrender_usershape(GVJ_t * job, char *name, pointf * AF, int n, boolean filled, char *imagescale, char *imagepos);
 
 /* layout */
 
