@@ -11,11 +11,17 @@
  * Contributors: See CVS logs. Details at http://www.graphviz.org/
  *************************************************************************/
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include	<string.h>
+#include        <sys/types.h>
+#include        <sys/stat.h>
+#ifdef HAVE_UNISTD_H
+#include <unistd.h>
+#else
+#include <compat_unistd.h>
+#endif
+
 #ifdef ENABLE_LTDL
 #include	<ltdl.h>
 #endif
@@ -35,7 +41,7 @@
 extern int strcasecmp(const char *s1, const char *s2);
 #endif
 
-#ifdef WIN32
+#ifdef _WIN32
 #define strdup(x) _strdup(x)
 #endif
 
@@ -50,7 +56,7 @@ static char *api_names[] = { APIS };    /* "render", "layout", ... */
 #undef ELEM
 
 /* translate a string api name to its type, or -1 on error */
-api_t gvplugin_api(char *str)
+api_t gvplugin_api(const char *str)
 {
     int api;
 
@@ -79,7 +85,12 @@ boolean gvplugin_install(GVC_t * gvc, api_t api, const char *typestr,
 {
     gvplugin_available_t *plugin, **pnext;
 #define TYPSIZ 63
-    char *p, pins[TYPSIZ + 1], pnxt[TYPSIZ + 1];
+    char *p, *t, pins[TYPSIZ + 1], pnxt[TYPSIZ + 1];
+
+    /* duplicate typestr to later save in the plugin list */
+    t = strdup(typestr);
+    if (t == NULL)
+        return FALSE;
 
     strncpy(pins, typestr, TYPSIZ);
     if ((p = strchr(pins, ':')))
@@ -113,7 +124,7 @@ boolean gvplugin_install(GVC_t * gvc, api_t api, const char *typestr,
     plugin = GNEW(gvplugin_available_t);
     plugin->next = *pnext;
     *pnext = plugin;
-    plugin->typestr = typestr;
+    plugin->typestr = t;
     plugin->quality = quality;
     plugin->package = package;
     plugin->typeptr = typeptr;  /* null if not loaded */
@@ -131,20 +142,20 @@ boolean gvplugin_install(GVC_t * gvc, api_t api, const char *typestr,
 static boolean gvplugin_activate(GVC_t * gvc, api_t api,
                                  const char *typestr, char *name, char *path, gvplugin_installed_t * typeptr)
 {
-    gvplugin_available_t **pnext;
+    gvplugin_available_t *pnext;
 
     /* point to the beginning of the linked list of plugins for this api */
-    pnext = &(gvc->apis[api]);
+    pnext = gvc->apis[api];
 
-    while (*pnext) {
-        if ((strcasecmp(typestr, (*pnext)->typestr) == 0)
-            && (strcasecmp(name, (*pnext)->package->name) == 0)
-            && ((*pnext)->package->path != 0)
-            && (strcasecmp(path, (*pnext)->package->path) == 0)) {
-            (*pnext)->typeptr = typeptr;
+    while (pnext) {
+        if ((strcasecmp(typestr, pnext->typestr) == 0)
+            && (strcasecmp(name, pnext->package->name) == 0)
+            && (pnext->package->path != 0)
+            && (strcasecmp(path, pnext->package->path) == 0)) {
+            pnext->typeptr = typeptr;
             return TRUE;
         }
-        pnext = &((*pnext)->next);
+        pnext = pnext->next;
     }
     return FALSE;
 }
@@ -160,6 +171,7 @@ gvplugin_library_t *gvplugin_library_load(GVC_t * gvc, char *path)
     static int lenp;
     char *libdir;
     char *suffix = "_LTX_library";
+    struct stat sb;
 
     if (!gvc->common.demand_loading)
         return NULL;
@@ -173,7 +185,7 @@ gvplugin_library_t *gvplugin_library_load(GVC_t * gvc, char *path)
         else
             p = gmalloc(lenp);
     }
-#ifdef WIN32
+#ifdef _WIN32
     if (path[1] == ':') {
 #else
     if (path[0] == '/') {
@@ -191,7 +203,12 @@ gvplugin_library_t *gvplugin_library_load(GVC_t * gvc, char *path)
     }
     hndl = lt_dlopen(p);
     if (!hndl) {
-        agerr(AGWARN, "Could not load \"%s\" - %s\n", p, (char *) lt_dlerror());
+        if ((stat(p, &sb)) == 0) {
+            agerr(AGWARN, "Could not load \"%s\" - %s\n", p, "It was found, so perhaps one of its dependents was not.  Try ldd.");
+        }
+        else {
+            agerr(AGWARN, "Could not load \"%s\" - %s\n", p, (char *) lt_dlerror());
+        }
         return NULL;
     }
     if (gvc->common.verbose >= 2)
@@ -199,7 +216,7 @@ gvplugin_library_t *gvplugin_library_load(GVC_t * gvc, char *path)
 
     s = strrchr(p, DIRSEP[0]);
     len = strlen(s);
-#if defined(WIN32) && !defined(__MINGW32__) && !defined(__CYGWIN__)
+#if defined(_WIN32) && !defined(__MINGW32__) && !defined(__CYGWIN__)
     if (len < strlen("/gvplugin_x")) {
 #else
     if (len < strlen("/libgvplugin_x")) {
@@ -208,7 +225,7 @@ gvplugin_library_t *gvplugin_library_load(GVC_t * gvc, char *path)
         return NULL;
     }
     sym = gmalloc(len + strlen(suffix) + 1);
-#if defined(WIN32) && !defined(__MINGW32__) && !defined(__CYGWIN__)
+#if defined(_WIN32) && !defined(__MINGW32__) && !defined(__CYGWIN__)
     strcpy(sym, s + 1);         /* strip leading "/"  */
 #else
     strcpy(sym, s + 4);         /* strip leading "/lib" or "/cyg" */
@@ -249,7 +266,7 @@ gvplugin_library_t *gvplugin_library_load(GVC_t * gvc, char *path)
 */
 gvplugin_available_t *gvplugin_load(GVC_t * gvc, api_t api, const char *str)
 {
-    gvplugin_available_t **pnext, *rv;
+    gvplugin_available_t *pnext, *rv;
     gvplugin_library_t *library;
     gvplugin_api_t *apis;
     gvplugin_installed_t *types;
@@ -276,8 +293,8 @@ gvplugin_available_t *gvplugin_load(GVC_t * gvc, api_t api, const char *str)
         reqpkg = NULL;
 
     /* iterate the linked list of plugins for this api */
-    for (pnext = &(gvc->apis[api]); *pnext; pnext = &((*pnext)->next)) {
-        strncpy(typ, (*pnext)->typestr, TYPBUFSIZ - 1);
+    for (pnext = gvc->apis[api]; pnext; pnext = pnext->next) {
+        strncpy(typ, pnext->typestr, TYPBUFSIZ - 1);
         dep = strchr(typ, ':');
         if (dep)
             *dep++ = '\0';
@@ -285,7 +302,7 @@ gvplugin_available_t *gvplugin_load(GVC_t * gvc, api_t api, const char *str)
             continue;           /* types empty or mismatched */
         if (dep && reqdep && strcmp(dep, reqdep))
             continue;           /* dependencies not empty, but mismatched */
-        if (!reqpkg || strcmp(reqpkg, (*pnext)->package->name) == 0) {
+        if (!reqpkg || strcmp(reqpkg, pnext->package->name) == 0) {
             /* found with no packagename constraints, or with required matching packagname */
 
             if (dep && (apidep != api)) /* load dependency if needed, continue if can't find */
@@ -294,7 +311,7 @@ gvplugin_available_t *gvplugin_load(GVC_t * gvc, api_t api, const char *str)
             break;
         }
     }
-    rv = *pnext;
+    rv = pnext;
 
     if (rv && rv->typeptr == NULL) {
         library = gvplugin_library_load(gvc, rv->package->path);
@@ -313,7 +330,7 @@ gvplugin_available_t *gvplugin_load(GVC_t * gvc, api_t api, const char *str)
         }
     }
 
-    /* one last check for successfull load */
+    /* one last check for successful load */
     if (rv && rv->typeptr == NULL)
         rv = NULL;
 
@@ -330,7 +347,7 @@ gvplugin_available_t *gvplugin_load(GVC_t * gvc, api_t api, const char *str)
 char *gvplugin_list(GVC_t * gvc, api_t api, const char *str)
 {
     static int first = 1;
-    gvplugin_available_t **pnext, **plugin;
+    const gvplugin_available_t *pnext, *plugin;
     char *bp;
     char *s, *p, *q, *typestr_last;
     boolean new = TRUE;
@@ -352,21 +369,21 @@ char *gvplugin_list(GVC_t * gvc, api_t api, const char *str)
         *p++ = '\0';
 
     /* point to the beginning of the linked list of plugins for this api */
-    plugin = &(gvc->apis[api]);
+    plugin = gvc->apis[api];
 
     if (p) {                    /* if str contains a ':', and if we find a match for the type,
                                    then just list the alternative paths for the plugin */
-        for (pnext = plugin; *pnext; pnext = &((*pnext)->next)) {
-            q = strdup((*pnext)->typestr);
+        for (pnext = plugin; pnext; pnext = pnext->next) {
+            q = strdup(pnext->typestr);
             if ((p = strchr(q, ':')))
                 *p++ = '\0';
             /* list only the matching type, or all types if s is an empty string */
             if (!s[0] || strcasecmp(s, q) == 0) {
                 /* list each member of the matching type as "type:path" */
                 agxbputc(&xb, ' ');
-                agxbput(&xb, (*pnext)->typestr);
+                agxbput(&xb, pnext->typestr);
                 agxbputc(&xb, ':');
-                agxbput(&xb, (*pnext)->package->name);
+                agxbput(&xb, pnext->package->name);
                 new = FALSE;
             }
             free(q);
@@ -376,9 +393,9 @@ char *gvplugin_list(GVC_t * gvc, api_t api, const char *str)
     if (new) {                  /* if the type was not found, or if str without ':',
                                    then just list available types */
         typestr_last = NULL;
-        for (pnext = plugin; *pnext; pnext = &((*pnext)->next)) {
+        for (pnext = plugin; pnext; pnext = pnext->next) {
             /* list only one instance of type */
-            q = strdup((*pnext)->typestr);
+            q = strdup(pnext->typestr);
             if ((p = strchr(q, ':')))
                 *p++ = '\0';
             if (!typestr_last || strcasecmp(typestr_last, q) != 0) {
@@ -412,10 +429,10 @@ char *gvplugin_list(GVC_t * gvc, api_t api, const char *str)
  * At present, the str argument is unused, but may be used to modify
  * the search as in gvplugin_list above.
  */
-char **gvPluginList(GVC_t * gvc, char *kind, int *sz, const char *str)
+char **gvPluginList(GVC_t * gvc, const char *kind, int *sz, const char *str)
 {
     int api;
-    gvplugin_available_t **pnext, **plugin;
+    const gvplugin_available_t *pnext, *plugin;
     int cnt = 0;
     char **list = NULL;
     char *p, *q, *typestr_last;
@@ -432,11 +449,11 @@ char **gvPluginList(GVC_t * gvc, char *kind, int *sz, const char *str)
     }
 
     /* point to the beginning of the linked list of plugins for this api */
-    plugin = &(gvc->apis[api]);
+    plugin = gvc->apis[api];
     typestr_last = NULL;
-    for (pnext = plugin; *pnext; pnext = &((*pnext)->next)) {
+    for (pnext = plugin; pnext; pnext = pnext->next) {
         /* list only one instance of type */
-        q = strdup((*pnext)->typestr);
+        q = strdup(pnext->typestr);
         if ((p = strchr(q, ':')))
             *p++ = '\0';
         if (!typestr_last || strcasecmp(typestr_last, q) != 0) {
@@ -482,7 +499,7 @@ Agraph_t *gvplugin_graph(GVC_t * gvc)
     Agedge_t *e;
     Agsym_t *a;
     gvplugin_package_t *package;
-    gvplugin_available_t **pnext;
+    const gvplugin_available_t *pnext;
     char bufa[100], *buf1, *buf2, bufb[100], *p, *q, *lq, *t;
     int api, neededge_loadimage, neededge_device;
 
@@ -524,9 +541,9 @@ Agraph_t *gvplugin_graph(GVC_t * gvc)
             agxset(ssg, a, "same");
             strcat(buf1, "_");
             buf2 = bufa + strlen(bufa);
-            for (pnext = &(gvc->apis[api]); *pnext; pnext = &((*pnext)->next)) {
-                if ((*pnext)->package == package) {
-                    t = q = strdup((*pnext)->typestr);
+            for (pnext = gvc->apis[api]; pnext; pnext = pnext->next) {
+                if (pnext->package == package) {
+                    t = q = strdup(pnext->typestr);
                     if ((p = strchr(q, ':')))
                         *p++ = '\0';
                     /* Now p = renderer, e.g. "gd"
@@ -700,9 +717,9 @@ Agraph_t *gvplugin_graph(GVC_t * gvc)
             strcpy(buf1, api_names[api]);
             strcat(buf1, "_");
             buf2 = bufa + strlen(bufa);
-            for (pnext = &(gvc->apis[api]); *pnext; pnext = &((*pnext)->next)) {
-                if ((*pnext)->package == package) {
-                    t = q = strdup((*pnext)->typestr);
+            for (pnext = gvc->apis[api]; pnext; pnext = pnext->next) {
+                if (pnext->package == package) {
+                    t = q = strdup(pnext->typestr);
                     if ((p = strchr(q, ':')))
                         *p++ = '\0';
                     /* Now p = renderer, e.g. "gd"
