@@ -18,6 +18,7 @@
 #include "ink.h"
 #include "agglomerative_bundling.h"
 #include "nearest_neighbor_graph.h"
+#include <string.h>
 
 #if OPENGL
 #include "gl.h"
@@ -132,8 +133,8 @@ static Agglomerative_Ink_Bundling Agglomerative_Ink_Bundling_establish(Agglomera
 	if (ip && jp){/* not the first level */
 	  ni = (ip[i+1] - ip[i]);/* number of edges represented by i */
 	  nj = (ip[jj+1] - ip[jj]);/* number of edges represented by jj */
-	  MEMCPY(pick, &(jp[ip[i]]), sizeof(int)*ni);
-	  MEMCPY(pick+ni, &(jp[ip[jj]]), sizeof(int)*nj);
+	  memcpy(pick, &(jp[ip[i]]), sizeof(int)*ni);
+	  memcpy(pick+ni, &(jp[ip[jj]]), sizeof(int)*nj);
 	} else {/* first level */
 	  pick[0] = i; pick[1] = jj;
 	  ni = nj = 1;
@@ -145,7 +146,7 @@ static Agglomerative_Ink_Bundling Agglomerative_Ink_Bundling_establish(Agglomera
 	if (Verbose && DEBUG) fprintf(stderr, "ink(%d)=%f, ink(%d->%d)=%f", i, inki, jj, jc, inkj);
 	if (ip) {
 	  ni = (ip[i+1] - ip[i]);/* number of edges represented by i */
-	  MEMCPY(pick, &(jp[ip[i]]), sizeof(int)*ni);
+	  memcpy(pick, &(jp[ip[i]]), sizeof(int)*ni);
 	} else {
 	  ni = 1; pick[0] = i; 
 	}
@@ -296,7 +297,7 @@ static Agglomerative_Ink_Bundling Agglomerative_Ink_Bundling_establish(Agglomera
 }
 
 
-
+#ifndef  NOTUSED
 static Agglomerative_Ink_Bundling Agglomerative_Ink_Bundling_aggressive_establish(Agglomerative_Ink_Bundling grid, int *pick, real angle_param, real angle){
   /* this does a true single-linkage clustering: find the edge that gives the best saving, merge, find again. 
      As oppose to: find the edge of node i that gives the best ink saving, merge, then do the same for node i+1, etc etc.
@@ -359,8 +360,8 @@ static Agglomerative_Ink_Bundling Agglomerative_Ink_Bundling_aggressive_establis
 	  if (ip && jp){/* not the first level */
 	    ni = (ip[i+1] - ip[i]);/* number of edges represented by i */
 	    nj = (ip[jj+1] - ip[jj]);/* number of edges represented by jj */
-	    MEMCPY(pick, &(jp[ip[i]]), sizeof(int)*ni);
-	    MEMCPY(pick+ni, &(jp[ip[jj]]), sizeof(int)*nj);
+	    memcpy(pick, &(jp[ip[i]]), sizeof(int)*ni);
+	    memcpy(pick+ni, &(jp[ip[jj]]), sizeof(int)*nj);
 	  } else {/* first level */
 	    pick[0] = i; pick[1] = jj;
 	    ni = nj = 1;
@@ -372,7 +373,7 @@ static Agglomerative_Ink_Bundling Agglomerative_Ink_Bundling_aggressive_establis
 	  if (Verbose && DEBUG) fprintf(stderr, "ink(%d)=%f, ink(%d->%d)=%f", i, inki, jj, jc, inkj);
 	  if (ip) {
 	    ni = (ip[i+1] - ip[i]);/* number of edges represented by i */
-	    MEMCPY(pick, &(jp[ip[i]]), sizeof(int)*ni);
+	    memcpy(pick, &(jp[ip[i]]), sizeof(int)*ni);
 	  } else {
 	    ni = 1; pick[0] = i; 
 	  }
@@ -541,6 +542,7 @@ static Agglomerative_Ink_Bundling Agglomerative_Ink_Bundling_aggressive_establis
   FREE(mask);
   return grid;
 }
+#endif
 
 static Agglomerative_Ink_Bundling Agglomerative_Ink_Bundling_new(SparseMatrix A0, pedge *edges, real angle_param, real angle){
   /* give a link of edges and their nearest neighbor graph, return a multilevel of edge bundling based on ink saving */
