@@ -14,6 +14,7 @@
 
 #include <ctype.h>
 #include <setjmp.h>
+#include <stdlib.h>
 #include "render.h"
 #include "pack.h"
 
@@ -74,14 +75,14 @@ static void push(stk_t* sp, Agnode_t * np)
 {
     if (sp->curp == sp->curblk->endp) {
 	if (sp->curblk->next == NULL) {
-	    blk_t *bp = GNEW(blk_t);
+	    blk_t *bp = malloc(sizeof(blk_t));
 	    if (bp == 0) {
 		agerr(AGERR, "gc: Out of memory\n");
 		longjmp(jbuf, 1);
 	    }
 	    bp->prev = sp->curblk;
 	    bp->next = NULL;
-	    bp->data = N_GNEW(BIGBUF, Agnode_t *);
+	    bp->data = calloc(BIGBUF, sizeof(Agnode_t *));
 	    if (bp->data == 0) {
 		agerr(AGERR, "gc: Out of memory\n");
 		longjmp(jbuf, 1);
@@ -174,7 +175,7 @@ setPrefix (char* pfx, int* lenp, char* buf, int buflen)
     if (len + 25 <= buflen)
         name = buf;
     else {
-        if (!(name = (char *) gmalloc(len + 25))) return NULL;
+        name = (char *) gmalloc(len + 25);
     }
     strcpy(name, pfx);
     *lenp = len;
@@ -497,7 +498,7 @@ static int clMarkFn (Agnode_t* n, int v)
  * with both endpoints in g.
  * Returns the number of edges added.
  */
-int node_induce(Agraph_t * g, Agraph_t* eg)
+static int node_induce(Agraph_t * g, Agraph_t* eg)
 {
     Agnode_t *n;
     Agedge_t *e;
@@ -514,17 +515,36 @@ int node_induce(Agraph_t * g, Agraph_t* eg)
     return e_cnt;
 }
 
+
+typedef struct {
+    Agrec_t h;
+    Agraph_t* orig;
+} orig_t;
+
+#define ORIG_REC "orig"
+
+Agraph_t*
+mapClust(Agraph_t *cl)
+{
+    orig_t* op = (orig_t*)aggetrec(cl, ORIG_REC, 0);
+    assert (op);
+    return op->orig;
+}
+
 /* projectG:
  * If any nodes of subg are in g, create a subgraph of g
  * and fill it with all nodes of subg in g and their induced
  * edges in subg. Copy the attributes of subg to g. Return the subgraph.
  * If not, return null.
+ * If subg is a cluster, the new subgraph will contain a pointer to it
+ * in the record "orig".
  */
 static Agraph_t *projectG(Agraph_t * subg, Agraph_t * g, int inCluster)
 {
     Agraph_t *proj = 0;
     Agnode_t *n;
     Agnode_t *m;
+    orig_t *op;
 
     for (n = agfstnode(subg); n; n = agnxtnode(subg, n)) {
 	if ((m = agfindnode(g, agnameof(n)))) {
@@ -540,6 +560,10 @@ static Agraph_t *projectG(Agraph_t * subg, Agraph_t * g, int inCluster)
     if (proj) {
 	node_induce(proj, subg);
 	agcopyattr(subg, proj);
+	if (isCluster(proj)) {
+	    op = agbindrec(proj,ORIG_REC, sizeof(orig_t), 0);
+	    op->orig = subg;
+	}
     }
 
     return proj;
@@ -573,6 +597,15 @@ subGInduce(Agraph_t* g, Agraph_t * out)
     subgInduce(g, out, 0);
 }
 
+/* cccomps:
+ * Decompose g into "connected" components, where nodes are connected
+ * either by an edge or by being in the same cluster. The components
+ * are returned in an array of subgraphs. ncc indicates how many components
+ * there are. The subgraphs use the prefix pfx in their names, if non-NULL.
+ * Note that cluster subgraph of the main graph, corresponding to a component,
+ * is cloned within the subgraph. Each cloned cluster contains a record pointing
+ * to the real cluster.
+ */
 Agraph_t **cccomps(Agraph_t * g, int *ncc, char *pfx)
 {
     Agraph_t *dg;
