@@ -53,7 +53,7 @@ typedef struct {
  * quadratic equation al^2 +bl + c, where a, b and
  * c are defined below.
  */
-static int computeStep(int ng, boxf* bbs, int margin)
+static int computeStep(int ng, boxf* bbs, unsigned int margin)
 {
     double l1, l2;
     double a, b, c, d, r;
@@ -108,8 +108,7 @@ static int cmpf(const void *X, const void *Y)
  * Mark cells crossed by line from cell p to cell q.
  * Bresenham's algorithm, from Graphics Gems I, pp. 99-100.
  */
-/* static  */
-void fillLine(pointf p, pointf q, PointSet * ps)
+static void fillLine(pointf p, pointf q, PointSet * ps)
 {
     int x1 = ROUND(p.x);
     int y1 = ROUND(p.y);
@@ -224,7 +223,8 @@ fillEdge(Agedge_t * e, point p, PointSet * ps, int dx, int dy,
  * the graph.
  */
 static void
-genBox(boxf bb0, ginfo * info, int ssize, int margin, point center, char* s)
+genBox(boxf bb0, ginfo * info, int ssize, unsigned int margin, point center,
+	char* s)
 {
     PointSet *ps;
     int W, H;
@@ -289,7 +289,7 @@ genPoly(Agraph_t * root, Agraph_t * g, ginfo * info,
     int x, y;
     int dx, dy;
     graph_t *subg;
-    int margin = pinfo->margin;
+    unsigned int margin = pinfo->margin;
     int doSplines = pinfo->doSplines;
     box bb;
 
@@ -488,7 +488,7 @@ placeFixed(ginfo * info, PointSet * ps, point * place, point center)
  */
 static void
 placeGraph(int i, ginfo * info, PointSet * ps, point * place, int step,
-	   int margin, boxf* bbs)
+	   unsigned int margin, boxf* bbs)
 {
     int x, y;
     int W, H;
@@ -919,7 +919,7 @@ point *putGraphs(int ng, Agraph_t ** gs, Agraph_t * root,
     int i, v;
     boxf* bbs;
     Agraph_t* g;
-    point* pts;
+    point* pts = NULL;
     char* s;
 
     if (ng <= 0) return NULL;
@@ -1052,7 +1052,7 @@ static void shiftGraph(Agraph_t * g, int dx, int dy)
     bb.UR.y += dy;
     GD_bb(g) = bb;
 
-    if (GD_label(g))
+    if (GD_label(g) && GD_label(g)->set)
 	MOVEPT(GD_label(g)->pos);
 
     for (i = 1; i <= GD_n_cluster(g); i++) {
@@ -1401,7 +1401,7 @@ getPackInfo(Agraph_t * g, pack_mode dflt, int dfltMargin, pack_info* pinfo)
 
     pinfo->margin = getPack(g, dfltMargin, dfltMargin);
     if (Verbose) {
-	fprintf (stderr, "  margin %d\n", pinfo->margin);
+	fprintf (stderr, "  margin %u\n", pinfo->margin);
     }
     pinfo->doSplines = 0;
     pinfo->fixed = 0;
