@@ -22,10 +22,6 @@
 #include "pathutil.h"
 #include "solvers.h"
 
-#ifdef DMALLOC
-#include "dmalloc.h"
-#endif
-
 #define EPSILON1 1E-3
 #define EPSILON2 1E-6
 
@@ -352,7 +348,7 @@ static int splinefits(Pedge_t * edges, int edgen, Ppoint_t pa,
 	    growops(opl + 4);
 	    for (pi = 1; pi < 4; pi++)
 		ops[opl].x = sps[pi].x, ops[opl++].y = sps[pi].y;
-#if DEBUG >= 1
+#if defined(DEBUG) && DEBUG >= 1
 	    fprintf(stderr, "success: %f %f\n", a, b);
 #endif
 	    return 1;
@@ -362,7 +358,7 @@ static int splinefits(Pedge_t * edges, int edgen, Ppoint_t pa,
 		growops(opl + 4);
 		for (pi = 1; pi < 4; pi++)
 		    ops[opl].x = sps[pi].x, ops[opl++].y = sps[pi].y;
-#if DEBUG >= 1
+#if defined(DEBUG) && DEBUG >= 1
 		fprintf(stderr, "forced straight line: %f %f\n", a, b);
 #endif
 		return 1;
@@ -374,7 +370,7 @@ static int splinefits(Pedge_t * edges, int edgen, Ppoint_t pa,
 	else
 	    a = b = 0;
     }
-#if DEBUG >= 1
+#if defined(DEBUG) && DEBUG >= 1
     fprintf(stderr, "failure\n");
 #endif
     return 0;
