@@ -1,4 +1,4 @@
-/* $Id: util.c,v 1.6 2011/01/25 16:30:50 ellson Exp $ $Revision: 1.6 $ */
+/* $Id$ $Revision$ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /*************************************************************************
@@ -16,10 +16,6 @@
 #include <stdlib.h>
 #include "pathutil.h"
 
-#ifdef DMALLOC
-#include "dmalloc.h"
-#endif
-
 #define ALLOC(size,ptr,type) (ptr? (type*)realloc(ptr,(size)*sizeof(type)):(type*)malloc((size)*sizeof(type)))
 
 Ppoly_t copypoly(Ppoly_t argpoly)
@@ -34,6 +30,12 @@ Ppoly_t copypoly(Ppoly_t argpoly)
     return rv;
 }
 
+void freePath(Ppolyline_t* p)
+{
+    free(p->ps);
+    free(p);
+}
+
 void freepoly(Ppoly_t argpoly)
 {
     free(argpoly.ps);
