@@ -14,10 +14,6 @@
 
 #include "vis.h"
 
-#ifdef DMALLOC
-#include "dmalloc.h"
-#endif
-
 	/* TRANSPARENT means router sees past colinear obstacles */
 #ifdef TRANSPARENT
 #define INTERSECT(a,b,c,d,e) intersect1((a),(b),(c),(d),(e))
@@ -89,7 +85,7 @@ static int open_intersect(Ppoint_t a, Ppoint_t b, Ppoint_t c, Ppoint_t d)
 /* inBetween:
  * Return true if c is in (a,b), assuming a,b,c are collinear.
  */
-int inBetween(Ppoint_t a, Ppoint_t b, Ppoint_t c)
+static int inBetween(Ppoint_t a, Ppoint_t b, Ppoint_t c)
 {
     if (a.x != b.x)		/* not vertical */
 	return (((a.x < c.x) && (c.x < b.x))
