@@ -2,7 +2,7 @@
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
-*      See the LICENSE file for copyright infomation.     *
+*      See the LICENSE file for copyright information.     *
 **********************************************************/
 
 #include "config.h"
@@ -14,13 +14,13 @@
 /*  FUNCTION:  RBTreeCreate */
 /**/
 /*  INPUTS:  All the inputs are names of functions.  CompFunc takes to */
-/*  void pointers to keys and returns 1 if the first arguement is */
+/*  void pointers to keys and returns 1 if the first argument is */
 /*  "greater than" the second.   DestFunc takes a pointer to a key and */
 /*  destroys it in the appropriate manner when the node containing that */
-/*  key is deleted.  InfoDestFunc is similiar to DestFunc except it */
-/*  recieves a pointer to the info of a node and destroys it. */
-/*  PrintFunc recieves a pointer to the key of a node and prints it. */
-/*  PrintInfo recieves a pointer to the info of a node and prints it. */
+/*  key is deleted.  InfoDestFunc is similar to DestFunc except it */
+/*  receives a pointer to the info of a node and destroys it. */
+/*  PrintFunc receives a pointer to the key of a node and prints it. */
+/*  PrintInfo receives a pointer to the info of a node and prints it. */
 /*  If RBTreePrint is never called the print functions don't have to be */
 /*  defined and NullFunction can be used.  */
 /**/
@@ -83,7 +83,7 @@ rb_red_blk_tree* RBTreeCreate( int (*CompFunc) (const void*,const void*),
 /*            accordingly. */
 /***********************************************************************/
 
-void LeftRotate(rb_red_blk_tree* tree, rb_red_blk_node* x) {
+static void LeftRotate(rb_red_blk_tree* tree, rb_red_blk_node* x) {
   rb_red_blk_node* y;
   rb_red_blk_node* nil=tree->nil;
 
@@ -138,7 +138,7 @@ void LeftRotate(rb_red_blk_tree* tree, rb_red_blk_node* x) {
 /*            accordingly. */
 /***********************************************************************/
 
-void RightRotate(rb_red_blk_tree* tree, rb_red_blk_node* y) {
+static void RightRotate(rb_red_blk_tree* tree, rb_red_blk_node* y) {
   rb_red_blk_node* x;
   rb_red_blk_node* nil=tree->nil;
 
@@ -185,11 +185,11 @@ void RightRotate(rb_red_blk_tree* tree, rb_red_blk_node* y) {
 /**/
 /*  EFFECTS:  Inserts z into the tree as if it were a regular binary tree */
 /*            using the algorithm described in _Introduction_To_Algorithms_ */
-/*            by Cormen et al.  This funciton is only intended to be called */
+/*            by Cormen et al.  This function is only intended to be called */
 /*            by the RBTreeInsert function and not by the user */
 /***********************************************************************/
 
-void TreeInsertHelp(rb_red_blk_tree* tree, rb_red_blk_node* z) {
+static void TreeInsertHelp(rb_red_blk_tree* tree, rb_red_blk_node* z) {
   /*  This function should only be called by InsertRBTree (see above) */
   rb_red_blk_node* x;
   rb_red_blk_node* y;
@@ -382,7 +382,7 @@ rb_red_blk_node* TreePredecessor(rb_red_blk_tree* tree, rb_red_blk_node* x) {
 /*    Note:    This function should only be called from RBTreePrint */
 /***********************************************************************/
 
-void InorderTreePrint(rb_red_blk_tree* tree, rb_red_blk_node* x) {
+static void InorderTreePrint(rb_red_blk_tree* tree, rb_red_blk_node* x) {
   rb_red_blk_node* nil=tree->nil;
   rb_red_blk_node* root=tree->root;
   if (x != tree->nil) {
@@ -418,7 +418,7 @@ void InorderTreePrint(rb_red_blk_tree* tree, rb_red_blk_node* x) {
 /*    Note:    This function should only be called by RBTreeDestroy */
 /***********************************************************************/
 
-void TreeDestHelper(rb_red_blk_tree* tree, rb_red_blk_node* x) {
+static void TreeDestHelper(rb_red_blk_tree* tree, rb_red_blk_node* x) {
   rb_red_blk_node* nil=tree->nil;
   if (x != nil) {
     TreeDestHelper(tree,x->left);
@@ -519,7 +519,7 @@ rb_red_blk_node* RBExactQuery(rb_red_blk_tree* tree, void* q) {
 /*    The algorithm from this function is from _Introduction_To_Algorithms_ */
 /***********************************************************************/
 
-void RBDeleteFixUp(rb_red_blk_tree* tree, rb_red_blk_node* x) {
+static void RBDeleteFixUp(rb_red_blk_tree* tree, rb_red_blk_node* x) {
   rb_red_blk_node* root=tree->root->left;
   rb_red_blk_node* w;
 
