@@ -11,13 +11,12 @@
  * Contributors: See CVS logs. Details at http://www.graphviz.org/
  *************************************************************************/
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include <time.h>
 #include <string.h>
 #include <math.h>
+#include <stdlib.h>
 
 #include "types.h"
 #include "memory.h"
@@ -250,7 +249,7 @@ real get_full_stress(SparseMatrix A, int dim, real *x, int weighting_scheme){
 #endif
 
 
-SparseMatrix ideal_distance_matrix(SparseMatrix A, int dim, real *x){
+static SparseMatrix ideal_distance_matrix(SparseMatrix A, int dim, real *x){
   /* find the ideal distance between edges, either 1, or |N[i] \Union N[j]| - |N[i] \Intersection N[j]|
    */
   SparseMatrix D;
@@ -821,11 +820,11 @@ real StressMajorizationSmoother_smooth(StressMajorizationSmoother sm, int dim, r
 
   Lwdd = SparseMatrix_copy(Lwd);
   m = Lw->m;
-  x0 = N_GNEW(dim*m,real);
+  x0 = calloc(dim*m, sizeof(real));
   if (!x0) goto RETURN;
 
-  x0 = MEMCPY(x0, x, sizeof(real)*dim*m);
-  y = N_GNEW(dim*m,real);
+  memcpy(x0, x, sizeof(real)*dim*m);
+  y = calloc(dim*m, sizeof(real));
   if (!y) goto RETURN;
 
   id = Lwd->ia; jd = Lwd->ja;
@@ -991,7 +990,7 @@ real StressMajorizationSmoother_smooth(StressMajorizationSmoother sm, int dim, r
 #endif
 
 
-    MEMCPY(x, y, sizeof(real)*m*dim);
+    memcpy(x, y, sizeof(real)*m*dim);
   }
 
 #ifdef DEBUG
@@ -1281,14 +1280,16 @@ void post_process_smoothing(int dim, SparseMatrix A, spring_electrical_control c
   case SMOOTHING_RNG:
   case SMOOTHING_TRIANGLE:{
     TriangleSmoother sm;
-    
-    if (ctrl->smoothing == SMOOTHING_RNG){
-      sm = TriangleSmoother_new(A, dim, 0, x, FALSE);
-    } else {
-      sm = TriangleSmoother_new(A, dim, 0, x, TRUE);
+
+    if (A->m > 2) {  /* triangles need at least 3 nodes */
+      if (ctrl->smoothing == SMOOTHING_RNG){
+        sm = TriangleSmoother_new(A, dim, 0, x, FALSE);
+      } else {
+        sm = TriangleSmoother_new(A, dim, 0, x, TRUE);
+      }
+      TriangleSmoother_smooth(sm, dim, x);
+      TriangleSmoother_delete(sm);
     }
-    TriangleSmoother_smooth(sm, dim, x);
-    TriangleSmoother_delete(sm);
     break;
   }
   case SMOOTHING_STRESS_MAJORIZATION_GRAPH_DIST:
