@@ -22,7 +22,7 @@
 #include "types.h"
 #include "globals.h"
 
-#define DEBUG_PRINT
+/* #define DEBUG_PRINT */
 
 struct uniform_stress_matmul_data{
   real alpha;
@@ -34,7 +34,7 @@ void Operator_uniform_stress_matmul_delete(Operator o){
   FREE(o->data);
 }
 
-real *Operator_uniform_stress_matmul_apply(Operator o, real *x, real *y){
+static real *Operator_uniform_stress_matmul_apply(Operator o, real *x, real *y){
   struct uniform_stress_matmul_data *d = (struct uniform_stress_matmul_data*) (o->data);
   SparseMatrix A = d->A;
   real alpha = d->alpha;
@@ -66,28 +66,28 @@ Operator Operator_uniform_stress_matmul(SparseMatrix A, real alpha){
 }
 
 
-real *Operator_matmul_apply(Operator o, real *x, real *y){
+static real *Operator_matmul_apply(Operator o, real *x, real *y){
   SparseMatrix A = (SparseMatrix) o->data;
   SparseMatrix_multiply_vector(A, x, &y, FALSE);
   return y;
 }
 
-Operator Operator_matmul_new(SparseMatrix A){
+static Operator Operator_matmul_new(SparseMatrix A){
   Operator o;
 
-  o = N_GNEW(1,struct Operator_struct);
+  o = GNEW(struct Operator_struct);
   o->data = (void*) A;
   o->Operator_apply = Operator_matmul_apply;
   return o;
 }
 
 
-void Operator_matmul_delete(Operator o){
+static void Operator_matmul_delete(Operator o){
   if (o) FREE(o);  
 }
 
 
-real* Operator_diag_precon_apply(Operator o, real *x, real *y){
+static real* Operator_diag_precon_apply(Operator o, real *x, real *y){
   int i, m;
   real *diag = (real*) o->data;
   m = (int) diag[0];
@@ -126,7 +126,7 @@ Operator Operator_uniform_stress_diag_precon_new(SparseMatrix A, real alpha){
 }
 
 
-Operator Operator_diag_precon_new(SparseMatrix A){
+static Operator Operator_diag_precon_new(SparseMatrix A){
   Operator o;
   real *diag;
   int i, j, m = A->m, *ia = A->ia, *ja = A->ja;
@@ -154,7 +154,7 @@ Operator Operator_diag_precon_new(SparseMatrix A){
   return o;
 }
 
-void Operator_diag_precon_delete(Operator o){
+static void Operator_diag_precon_delete(Operator o){
   if (o->data) FREE(o->data);
   if (o) FREE(o);
 }
@@ -176,8 +176,8 @@ static real conjugate_gradient(Operator A, Operator precon, int n, real *x, real
 
   res0 = res = sqrt(vector_product(n, r, r))/n;
 #ifdef DEBUG_PRINT
-    if (Verbose && 0){
-      fprintf(stderr, "   cg iter = %d, residual = %g\n", iter, res);
+    if (Verbose){
+      fprintf(stderr, "on entry, cg iter = %d of %d, residual = %g, tol = %g\n", iter, maxit, res, tol);
     }
 #endif
 
@@ -189,7 +189,7 @@ static real conjugate_gradient(Operator A, Operator precon, int n, real *x, real
       beta = rho/rho_old;
       p = vector_saxpy(n, z, p, beta);
     } else {
-      MEMCPY(p, z, sizeof(real)*n);
+      memcpy(p, z, sizeof(real)*n);
     }
 
     q = Ax(A, p, q);
@@ -203,7 +203,7 @@ static real conjugate_gradient(Operator A, Operator precon, int n, real *x, real
 
 #ifdef DEBUG_PRINT
     if (Verbose && 0){
-      fprintf(stderr, "   cg iter = %d, residual = %g\n", iter, res);
+      fprintf(stderr, "   cg iter = %d, residual = %g, relative res = %g\n", iter, res, res/res0);
     }
 #endif
 
@@ -217,8 +217,8 @@ static real conjugate_gradient(Operator A, Operator precon, int n, real *x, real
 #endif
 
 #ifdef DEBUG_PRINT
-  if (Verbose && 0){
-    fprintf(stderr, "   cg iter = %d, residual = %g\n", iter, res);
+  if (Verbose){
+    fprintf(stderr, "   cg iter = %d, residual = %g, relative res = %g\n", iter, res, res/res0);
   }
 #endif
   return res;
@@ -246,6 +246,53 @@ real cg(Operator Ax, Operator precond, int n, int dim, real *x0, real *rhs, real
 
 }
 
+static real* jacobi(SparseMatrix A, int dim, real *x0, real *rhs, int maxit, int *flag){
+  /* maxit iteration of jacobi */
+  real *x, *y, *b, sum, diag, *a;
+  int k, i, j, n = A->n, *ia, *ja, iter;
+  x = MALLOC(sizeof(real)*n);
+  y = MALLOC(sizeof(real)*n);
+  b = MALLOC(sizeof(real)*n);
+  assert(A->type = MATRIX_TYPE_REAL);
+  ia = A->ia; ja = A->ja; a = (real*) A->a;
+
+  for (k = 0; k < dim; k++){
+    for (i = 0; i < n; i++) {
+      x[i] = x0[i*dim+k];
+      b[i] = rhs[i*dim+k];
+    }
+
+    for (iter = 0; iter < maxit; iter++){
+      for (i = 0; i < n; i++){
+	sum = 0; diag = 0;
+	for (j = ia[i]; j < ia[i+1]; j++){
+	  if (ja[j] != i){
+	    sum += a[j]*x[ja[j]];
+	  } else {
+	    diag = a[j];
+	  }
+	}
+	if (sum == 0) fprintf(stderr,"neighb=%d\n",ia[i+1]-ia[i]);
+	assert(diag != 0);
+	y[i] = (b[i] - sum)/diag;
+
+      }
+      memcpy(x, y, sizeof(real)*n);
+    }
+
+    for (i = 0; i < n; i++) {
+      rhs[i*dim+k] = x[i];
+    }
+  }
+
+
+  FREE(x);
+  FREE(y);
+  FREE(b);
+  return rhs;
+
+}
+
 real SparseMatrix_solve(SparseMatrix A, int dim, real *x0, real *rhs, real tol, int maxit, int method, int *flag){
   Operator Ax, precond;
   int n = A->m;
@@ -260,6 +307,10 @@ real SparseMatrix_solve(SparseMatrix A, int dim, real *x0, real *rhs, real tol,
     Operator_matmul_delete(Ax);
     Operator_diag_precon_delete(precond);
     break;
+  case SOLVE_METHOD_JACOBI:{
+    jacobi(A, dim, x0, rhs, maxit, flag);
+    break;
+  }
   default:
     assert(0);
     break;
