@@ -45,7 +45,7 @@ UniformStressSmoother UniformStressSmoother_new(int dim, SparseMatrix A, real *x
   ((real*) sm->data)[1] = M;
   sm->data_deallocator = FREE;
   sm->tol_cg = 0.01;
-  sm->maxit_cg = sqrt((double) A->m);
+  sm->maxit_cg = (int)sqrt((double) A->m);
 
   /* Lw and Lwd have diagonals */
   sm->Lw = SparseMatrix_new(m, m, A->nz + m, MATRIX_TYPE_REAL, FORMAT_CSR);
@@ -103,13 +103,13 @@ void UniformStressSmoother_delete(UniformStressSmoother sm){
 
 }
 
-real UniformStressSmoother_smooth(UniformStressSmoother sm, int dim, real *x, int maxit_sm) {
+static real UniformStressSmoother_smooth(UniformStressSmoother sm, int dim, real *x, int maxit_sm) {
 
   return StressMajorizationSmoother_smooth(sm, dim, x, maxit_sm, 0.001);
 
 }
 
-SparseMatrix get_distance_matrix(SparseMatrix A, real scaling){
+static SparseMatrix get_distance_matrix(SparseMatrix A, real scaling){
   /* get a distance matrix from a graph, at the moment we just symmetrize the matrix. At the moment if the matrix is not real,
    we just assume distance of 1 among edges. Then we apply scaling to the entire matrix */
   SparseMatrix B;
