@@ -155,7 +155,7 @@ void vector_float_take(int n, float *v, int m, int *p, float **u){
   
 }
 
-int comp_ascend(const void *s1, const void *s2){
+static int comp_ascend(const void *s1, const void *s2){
   real *ss1, *ss2;
   ss1 = (real*) s1;
   ss2 = (real*) s2;
@@ -168,7 +168,7 @@ int comp_ascend(const void *s1, const void *s2){
   return 0;
 }
 
-int comp_descend(const void *s1, const void *s2){
+static int comp_descend(const void *s1, const void *s2){
   real *ss1, *ss2;
   ss1 = (real*) s1;
   ss2 = (real*) s2;
@@ -180,7 +180,7 @@ int comp_descend(const void *s1, const void *s2){
   }
   return 0;
 }
-int comp_descend_int(const void *s1, const void *s2){
+static int comp_descend_int(const void *s1, const void *s2){
   int *ss1, *ss2;
   ss1 = (int*) s1;
   ss2 = (int*) s2;
@@ -193,7 +193,7 @@ int comp_descend_int(const void *s1, const void *s2){
   return 0;
 }
 
-int comp_ascend_int(const void *s1, const void *s2){
+static int comp_ascend_int(const void *s1, const void *s2){
   int *ss1, *ss2;
   ss1 = (int*) s1;
   ss2 = (int*) s2;
@@ -213,7 +213,7 @@ void vector_ordering(int n, real *v, int **p, int ascending){
      or
 
      give the position of the smallest, second smallest etc  in vector v if ascending = TRUE.
-     results in p. If *p == NULL, p is asigned.
+     results in p. If *p == NULL, p is assigned.
 
      ascending: TRUE if v[p] is from small to large.
   */
