@@ -39,15 +39,11 @@
 
 #include <stdlib.h>
 #include <stdio.h>
+#include <inttypes.h>
 #include "tclhandle.h"
 /* Added 2000-09-19 by KG for memcpy, ... decls */
 #include <string.h>
 
-#ifdef DMALLOC
-#include "dmalloc.h"
-#endif
-
-
 /*
  * Variable set to contain the alignment factor (in bytes) for this machine.
  * It is set on the first table initialization.
@@ -128,7 +124,7 @@ static void tclhandleExpandTable(tblHeader_pt tblHdrPtr, int neededIdx)
  *-----------------------------------------------------------------------------
  */
 entryHeader_pt tclhandleAlloc(tblHeader_pt headerPtr, char *handle,
-			      unsigned long *entryIdxPtr)
+			      uint64_t *entryIdxPtr)
 {
     tblHeader_pt tblHdrPtr = (tblHeader_pt) headerPtr;
     entryHeader_pt entryPtr;
@@ -171,8 +167,8 @@ tblHeader_pt tclhandleInit(char *prefix, int entrySize, int initEntries)
      */
     if (tclhandleEntryAlignment == 0) {
 	tclhandleEntryAlignment = sizeof(void *);
-	if (sizeof(unsigned long) > tclhandleEntryAlignment)
-	    tclhandleEntryAlignment = sizeof(unsigned long);
+	if (sizeof(uint64_t) > tclhandleEntryAlignment)
+	    tclhandleEntryAlignment = sizeof(uint64_t);
 	if (sizeof(double) > tclhandleEntryAlignment)
 	    tclhandleEntryAlignment = sizeof(double);
     }
@@ -274,9 +270,9 @@ int tclhandleReset(tblHeader_pt tblHdrPtr, int initEntries)
  *-----------------------------------------------------------------------------
  */
 int tclhandleIndex(tblHeader_pt tblHdrPtr, char *handle,
-		   unsigned long *entryIdxPtr)
+		   uint64_t *entryIdxPtr)
 {
-    unsigned long entryIdx;
+    uint64_t entryIdx;
 
     if ((sscanf(handle, tblHdrPtr->handleFormat, &entryIdx)) != 1)
 	return TCL_ERROR;
@@ -297,7 +293,7 @@ int tclhandleIndex(tblHeader_pt tblHdrPtr, char *handle,
  *-----------------------------------------------------------------------------
  */
 void tclhandleString(tblHeader_pt tblHdrPtr, char *handle,
-		     unsigned long entryIdx)
+		     uint64_t entryIdx)
 {
     sprintf(handle, tblHdrPtr->handleFormat, entryIdx);
 }
@@ -311,10 +307,10 @@ void tclhandleString(tblHeader_pt tblHdrPtr, char *handle,
  *   o headerPtr (I) - A pointer to the table header.
  *   o index (I) - The index of an entry.
  * Returns:
- *   A pointer to the entry, or NULL if an error occured.
+ *   A pointer to the entry, or NULL if an error occurred.
  *-----------------------------------------------------------------------------
  */
-void *tclhandleXlateIndex(tblHeader_pt headerPtr, unsigned long entryIdx)
+void *tclhandleXlateIndex(tblHeader_pt headerPtr, uint64_t entryIdx)
 {
     tblHeader_pt tblHdrPtr = headerPtr;
     entryHeader_pt entryPtr;
@@ -337,12 +333,12 @@ void *tclhandleXlateIndex(tblHeader_pt headerPtr, unsigned long entryIdx)
  *   o headerPtr (I) - A pointer to the table header.
  *   o handle (I) - The handle string -- <prefix><int>
  * Returns:
- *   A pointer to the entry, or NULL if an error occured.
+ *   A pointer to the entry, or NULL if an error occurred.
  *-----------------------------------------------------------------------------
  */
 void *tclhandleXlate(tblHeader_pt tblHdrPtr, char *handle)
 {
-    unsigned long entryIdx;
+    uint64_t entryIdx;
 
     if ((tclhandleIndex(tblHdrPtr, handle, &entryIdx)) != TCL_OK)
 	return NULL;
@@ -358,10 +354,10 @@ void *tclhandleXlate(tblHeader_pt tblHdrPtr, char *handle)
  *   o index (I) - The index of an entry.
  *----------------------------------------------------------------------------
  * Returns:
- *   The contents of the entry, if success, or NULL if an error occured.
+ *   The contents of the entry, if success, or NULL if an error occurred.
  *----------------------------------------------------------------------------
  */
-void *tclhandleFreeIndex(tblHeader_pt headerPtr, unsigned long entryIdx)
+void *tclhandleFreeIndex(tblHeader_pt headerPtr, uint64_t entryIdx)
 {
     tblHeader_pt tblHdrPtr = headerPtr;
     entryHeader_pt entryPtr, freeentryPtr;
@@ -391,12 +387,12 @@ void *tclhandleFreeIndex(tblHeader_pt headerPtr, unsigned long entryIdx)
  *   o handle (I) - The handle of an entry.
  *----------------------------------------------------------------------------
  * Returns:
- *   The contents of the entry, if success, or NULL if an error occured.
+ *   The contents of the entry, if success, or NULL if an error occurred.
  *----------------------------------------------------------------------------
  */
 void *tclhandleFree(tblHeader_pt tblHdrPtr, char *handle)
 {
-    unsigned long entryIdx;
+    uint64_t entryIdx;
 
     if ((tclhandleIndex(tblHdrPtr, handle, &entryIdx)) != TCL_OK)
 	return NULL;
